@@ -1,17 +1,17 @@
 #!/usr/bin/env python
 
-import click
-
+from fandogh_cli.namespace_commands import namespace
 from fandogh_cli.secret_commands import secret
-from .domain_commands import domain
-from .image_commands import image
-from .service_commands import service
-from .managed_service_commands import managed_service
-
 from .base_commands import FandoghCommand
-from .presenter import present
-from .config import *
+from .domain_commands import domain
+from .exec_commands import exec_command
 from .fandogh_client import *
+from .image_commands import image
+from .managed_service_commands import managed_service
+from .presenter import present
+from .service_commands import service
+from .source_commands import source
+from .volume_commands import volume
 
 
 @click.group("cli")
@@ -32,7 +32,6 @@ def login(username, password):
 
     message = present(lambda: handle_token(), post='Logged in successfully')
 
-    click.clear()
     click.echo(" ___  _   _  _  __   _   __  _ _    __  _   _  _ _  __  ")
     click.echo("| __|/ \ | \| ||  \ / \ / _|| U |  / _|| | / \| | ||  \ ")
     click.echo("| _|| o || \  || o | o | |_n|   | ( (_ | |( o ) U || o )")
@@ -42,19 +41,17 @@ def login(username, password):
     click.echo('Welcome to Fandogh Cloud, you can start using our PaaS as quickly as a link click, Try it below:\n')
     click.echo('https://docs.fandogh.cloud/docs/getting-started.html\n')
 
-    #TODO
-# click.echo(" ___  _   _  _  __   _   __  _ _ ")
-#         click.echo("| __|/ \ | \| ||  \ / \ / _|| U |")
-#         click.echo("| _|| o || \  || o | o | |_n|   |")
-#         click.echo("|_| |_n_||_|\_||__/ \_/ \__/|_n_|")
-#         click.echo("                                 ")
 
 base.add_command(login)
 base.add_command(image)
+base.add_command(source)
 base.add_command(service)
 base.add_command(managed_service)
 base.add_command(domain)
 base.add_command(secret)
+base.add_command(namespace)
+base.add_command(exec_command)
+base.add_command(volume)
 
 if __name__ == '__main__':
     base()
